//line parser.y:2
package main

import __yyfmt__ "fmt"

//line parser.y:2
import (
	"bytes"
	"fmt"
	"io"
	"os"
)

type node struct {
	name       string
	children   []node
	attributes map[string]string
}

func (n node) String() string {
	buf := new(bytes.Buffer)
	n.print(buf, " ")
	return buf.String()
}

func (n node) print(out io.Writer, indent string) {
	if len(n.attributes) > 0 {
		fmt.Fprintf(out, "\n%v%v %s", indent, n.name, n.attributes)
	} else {
		fmt.Fprintf(out, "\n%v%v", indent, n.name)
	}
	for _, nn := range n.children {
		nn.print(out, indent+"  ")
	}
}

func Node(name string) node {
	return node{name: name, attributes: make(map[string]string)}
}

func (n node) append(nn ...node) node {
	n.children = append(n.children, nn...)
	return n
}

func (n node) attribute(key string, value string) node {
	n.attributes[key] = value
	return n
}

//line parser.y:50
type yySymType struct {
	yys   int
	node  node
	token string
	value string
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EVAL = 57348
const T_REQUIRE = 57349
const T_REQUIRE_ONCE = 57350
const T_LOGICAL_OR = 57351
const T_LOGICAL_XOR = 57352
const T_LOGICAL_AND = 57353
const T_PRINT = 57354
const T_YIELD = 57355
const T_DOUBLE_ARROW = 57356
const T_YIELD_FROM = 57357
const T_PLUS_EQUAL = 57358
const T_MINUS_EQUAL = 57359
const T_MUL_EQUAL = 57360
const T_DIV_EQUAL = 57361
const T_CONCAT_EQUAL = 57362
const T_MOD_EQUAL = 57363
const T_AND_EQUAL = 57364
const T_OR_EQUAL = 57365
const T_XOR_EQUAL = 57366
const T_SL_EQUAL = 57367
const T_SR_EQUAL = 57368
const T_POW_EQUAL = 57369
const T_COALESCE = 57370
const T_BOOLEAN_OR = 57371
const T_BOOLEAN_AND = 57372
const T_IS_EQUAL = 57373
const T_IS_NOT_EQUAL = 57374
const T_IS_IDENTICAL = 57375
const T_IS_NOT_IDENTICAL = 57376
const T_SPACESHIP = 57377
const T_IS_SMALLER_OR_EQUAL = 57378
const T_IS_GREATER_OR_EQUAL = 57379
const T_SL = 57380
const T_SR = 57381
const T_INSTANCEOF = 57382
const T_INC = 57383
const T_DEC = 57384
const T_INT_CAST = 57385
const T_DOUBLE_CAST = 57386
const T_STRING_CAST = 57387
const T_ARRAY_CAST = 57388
const T_OBJECT_CAST = 57389
const T_BOOL_CAST = 57390
const T_UNSET_CAST = 57391
const T_POW = 57392
const T_NEW = 57393
const T_CLONE = 57394
const T_NOELSE = 57395
const T_ELSEIF = 57396
const T_ELSE = 57397
const T_ENDIF = 57398
const T_STATIC = 57399
const T_ABSTRACT = 57400
const T_FINAL = 57401
const T_PRIVATE = 57402
const T_PROTECTED = 57403
const T_PUBLIC = 57404
const T_EXIT = 57405
const T_IF = 57406
const T_LNUMBER = 57407
const T_DNUMBER = 57408
const T_STRING = 57409
const T_STRING_VARNAME = 57410
const T_VARIABLE = 57411
const T_NUM_STRING = 57412
const T_INLINE_HTML = 57413
const T_CHARACTER = 57414
const T_BAD_CHARACTER = 57415
const T_ENCAPSED_AND_WHITESPACE = 57416
const T_CONSTANT_ENCAPSED_STRING = 57417
const T_ECHO = 57418
const T_DO = 57419
const T_WHILE = 57420
const T_ENDWHILE = 57421
const T_FOR = 57422
const T_ENDFOR = 57423
const T_FOREACH = 57424
const T_ENDFOREACH = 57425
const T_DECLARE = 57426
const T_ENDDECLARE = 57427
const T_AS = 57428
const T_SWITCH = 57429
const T_ENDSWITCH = 57430
const T_CASE = 57431
const T_DEFAULT = 57432
const T_BREAK = 57433
const T_CONTINUE = 57434
const T_GOTO = 57435
const T_FUNCTION = 57436
const T_CONST = 57437
const T_RETURN = 57438
const T_TRY = 57439
const T_CATCH = 57440
const T_FINALLY = 57441
const T_THROW = 57442
const T_USE = 57443
const T_INSTEADOF = 57444
const T_GLOBAL = 57445
const T_VAR = 57446
const T_UNSET = 57447
const T_ISSET = 57448
const T_EMPTY = 57449
const T_HALT_COMPILER = 57450
const T_CLASS = 57451
const T_TRAIT = 57452
const T_INTERFACE = 57453
const T_EXTENDS = 57454
const T_IMPLEMENTS = 57455
const T_OBJECT_OPERATOR = 57456
const T_LIST = 57457
const T_ARRAY = 57458
const T_CALLABLE = 57459
const T_CLASS_C = 57460
const T_TRAIT_C = 57461
const T_METHOD_C = 57462
const T_FUNC_C = 57463
const T_LINE = 57464
const T_FILE = 57465
const T_COMMENT = 57466
const T_DOC_COMMENT = 57467
const T_OPEN_TAG = 57468
const T_OPEN_TAG_WITH_ECHO = 57469
const T_CLOSE_TAG = 57470
const T_WHITESPACE = 57471
const T_START_HEREDOC = 57472
const T_END_HEREDOC = 57473
const T_DOLLAR_OPEN_CURLY_BRACES = 57474
const T_CURLY_OPEN = 57475
const T_PAAMAYIM_NEKUDOTAYIM = 57476
const T_NAMESPACE = 57477
const T_NS_C = 57478
const T_DIR = 57479
const T_NS_SEPARATOR = 57480
const T_ELLIPSIS = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"','",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_PRINT",
	"T_YIELD",
	"T_DOUBLE_ARROW",
	"T_YIELD_FROM",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"'?'",
	"':'",
	"T_COALESCE",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"'&'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_SPACESHIP",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'+'",
	"'-'",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"'!'",
	"T_INSTANCEOF",
	"'~'",
	"T_INC",
	"T_DEC",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"'@'",
	"T_POW",
	"'['",
	"T_NEW",
	"T_CLONE",
	"T_NOELSE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"';'",
	"'{'",
	"'}'",
	"'('",
	"')'",
	"']'",
	"'$'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line parser.y:796
const src = `<?php

abstract class test {
    public static $a ,$b = $c;
}

`

func main() {
	yyDebug = 0
	yyErrorVerbose = true
	l := newLexer(bytes.NewBufferString(src), os.Stdout, "file.name")
	yyParse(l)
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 90,
	159, 46,
	-2, 301,
	-1, 300,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 273,
	-1, 301,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 274,
	-1, 302,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 275,
	-1, 303,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 276,
	-1, 304,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 277,
	-1, 305,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 278,
	-1, 306,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 279,
	-1, 307,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 280,
	-1, 308,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 281,
	-1, 369,
	163, 213,
	-2, 218,
}

const yyPrivate = 57344

const yyLast = 4264

var yyAct = [...]int{

	23, 152, 447, 483, 411, 509, 467, 72, 408, 406,
	449, 393, 414, 438, 409, 423, 371, 159, 159, 159,
	149, 317, 170, 264, 269, 169, 4, 313, 163, 166,
	204, 37, 69, 69, 488, 557, 552, 154, 542, 517,
	516, 478, 479, 233, 507, 458, 236, 237, 238, 239,
	240, 68, 242, 444, 244, 245, 246, 247, 248, 249,
	250, 251, 252, 253, 254, 255, 256, 478, 479, 391,
	541, 164, 494, 492, 446, 234, 235, 366, 369, 352,
	327, 325, 243, 233, 241, 72, 242, 232, 244, 245,
	254, 255, 202, 201, 512, 464, 200, 157, 156, 153,
	151, 174, 176, 175, 257, 389, 558, 527, 510, 70,
	70, 410, 503, 495, 370, 395, 324, 282, 279, 277,
	477, 198, 258, 199, 172, 173, 177, 179, 178, 191,
	192, 189, 190, 193, 194, 195, 196, 197, 187, 188,
	181, 182, 180, 183, 185, 186, 203, 397, 559, 412,
	413, 550, 537, 523, 267, 513, 72, 271, 272, 184,
	427, 428, 429, 426, 425, 424, 69, 151, 416, 506,
	475, 415, 472, 283, 284, 285, 286, 287, 288, 289,
	290, 291, 292, 293, 294, 295, 296, 297, 298, 299,
	300, 301, 302, 303, 304, 305, 306, 307, 308, 309,
	311, 443, 315, 151, 442, 319, 441, 422, 439, 437,
	353, 328, 396, 321, 275, 274, 412, 413, 330, 332,
	333, 334, 335, 336, 337, 338, 339, 340, 341, 342,
	343, 365, 314, 344, 388, 416, 511, 326, 415, 273,
	261, 260, 346, 70, 347, 465, 259, 500, 427, 428,
	429, 426, 425, 424, 436, 268, 66, 67, 349, 456,
	457, 544, 502, 514, 478, 479, 468, 281, 278, 276,
	529, 416, 167, 151, 415, 481, 478, 479, 318, 350,
	323, 358, 322, 170, 427, 428, 429, 426, 425, 424,
	211, 205, 214, 216, 215, 422, 187, 188, 181, 182,
	180, 183, 185, 186, 212, 213, 356, 209, 359, 357,
	184, 361, 461, 208, 543, 497, 39, 184, 471, 329,
	206, 489, 547, 504, 367, 280, 372, 459, 373, 164,
	363, 374, 375, 418, 194, 195, 196, 197, 187, 188,
	181, 182, 180, 183, 185, 186, 354, 362, 74, 379,
	210, 158, 75, 384, 271, 386, 183, 185, 186, 184,
	1, 390, 181, 182, 180, 183, 185, 186, 402, 160,
	161, 265, 184, 266, 5, 382, 8, 466, 385, 421,
	420, 184, 419, 455, 524, 435, 403, 417, 401, 399,
	398, 392, 316, 450, 448, 314, 394, 312, 451, 168,
	433, 165, 454, 440, 178, 191, 192, 189, 190, 193,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 162, 387, 532, 462, 270, 445, 463, 381,
	11, 36, 10, 35, 41, 184, 473, 469, 271, 38,
	405, 404, 496, 407, 33, 262, 2, 451, 150, 487,
	3, 71, 207, 480, 470, 482, 486, 499, 460, 0,
	0, 0, 476, 0, 0, 0, 0, 484, 0, 498,
	0, 0, 0, 505, 0, 0, 394, 501, 0, 508,
	0, 0, 0, 0, 491, 0, 0, 515, 0, 0,
	451, 519, 0, 451, 0, 522, 0, 526, 0, 525,
	518, 0, 0, 0, 0, 531, 528, 0, 0, 0,
	530, 536, 0, 0, 535, 0, 0, 0, 0, 0,
	539, 0, 0, 0, 0, 0, 0, 0, 0, 546,
	0, 533, 0, 0, 0, 0, 548, 549, 0, 0,
	484, 0, 451, 0, 551, 0, 0, 0, 555, 553,
	0, 348, 540, 0, 0, 84, 85, 86, 87, 88,
	560, 91, 92, 93, 89, 90, 198, 65, 199, 172,
	173, 177, 179, 178, 191, 192, 189, 190, 193, 194,
	195, 196, 197, 187, 188, 181, 182, 180, 183, 185,
	186, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	45, 46, 0, 0, 184, 0, 47, 94, 48, 43,
	44, 55, 56, 57, 58, 59, 60, 61, 62, 0,
	0, 95, 82, 0, 98, 99, 100, 76, 77, 78,
	79, 80, 81, 96, 97, 0, 0, 73, 0, 69,
	0, 0, 0, 0, 0, 0, 101, 102, 103, 104,
	105, 106, 107, 108, 109, 110, 111, 128, 129, 130,
	131, 132, 122, 123, 124, 125, 126, 112, 113, 114,
	115, 116, 117, 118, 119, 120, 121, 83, 0, 140,
	138, 139, 135, 136, 0, 127, 133, 134, 141, 142,
	144, 143, 145, 146, 0, 0, 0, 0, 0, 155,
	51, 52, 53, 54, 0, 137, 148, 147, 63, 64,
	0, 65, 0, 49, 0, 0, 70, 173, 177, 179,
	178, 191, 192, 189, 190, 193, 194, 195, 196, 197,
	187, 188, 181, 182, 180, 183, 185, 186, 0, 0,
	0, 0, 0, 0, 45, 46, 0, 0, 0, 0,
	47, 184, 48, 43, 44, 55, 56, 57, 58, 59,
	60, 61, 62, 0, 0, 0, 42, 0, 0, 0,
	0, 20, 66, 67, 0, 0, 0, 0, 40, 0,
	0, 31, 0, 69, 0, 22, 0, 0, 0, 0,
	21, 13, 12, 0, 14, 0, 25, 0, 26, 0,
	0, 15, 0, 0, 0, 16, 17, 30, 32, 0,
	18, 28, 0, 0, 29, 0, 0, 19, 0, 24,
	0, 50, 0, 34, 155, 51, 52, 53, 54, 0,
	0, 0, 0, 63, 64, 0, 65, 191, 192, 189,
	190, 193, 194, 195, 196, 197, 187, 188, 181, 182,
	180, 183, 185, 186, 27, 9, 561, 49, 0, 0,
	70, 0, 0, 0, 0, 0, 0, 184, 0, 45,
	46, 0, 0, 0, 0, 47, 0, 48, 43, 44,
	55, 56, 57, 58, 59, 60, 61, 62, 0, 0,
	0, 42, 0, 0, 0, 0, 20, 66, 67, 0,
	0, 0, 0, 40, 0, 0, 31, 0, 69, 0,
	22, 0, 0, 0, 0, 21, 13, 12, 0, 14,
	556, 25, 0, 26, 0, 0, 15, 0, 0, 0,
	16, 17, 30, 32, 0, 18, 28, 0, 0, 29,
	0, 0, 19, 0, 24, 0, 50, 0, 34, 155,
	51, 52, 53, 54, 0, 0, 0, 0, 63, 64,
	0, 65, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 27,
	9, 0, 49, 0, 0, 70, 0, 0, 0, 0,
	0, 0, 0, 0, 45, 46, 0, 0, 0, 0,
	47, 0, 48, 43, 44, 55, 56, 57, 58, 59,
	60, 61, 62, 0, 0, 0, 42, 0, 0, 0,
	0, 20, 66, 67, 0, 0, 0, 0, 40, 0,
	0, 31, 0, 69, 0, 22, 0, 0, 0, 0,
	21, 13, 12, 0, 14, 0, 25, 0, 26, 0,
	0, 15, 0, 0, 0, 16, 17, 30, 32, 0,
	18, 28, 0, 0, 29, 0, 0, 19, 0, 24,
	0, 50, 0, 34, 155, 51, 52, 53, 54, 0,
	0, 0, 0, 63, 64, 0, 65, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 27, 9, 554, 49, 0, 0,
	70, 0, 0, 0, 0, 0, 0, 0, 0, 45,
	46, 0, 0, 0, 0, 47, 0, 48, 43, 44,
	55, 56, 57, 58, 59, 60, 61, 62, 0, 0,
	0, 42, 0, 0, 0, 0, 20, 66, 67, 0,
	0, 0, 0, 40, 0, 0, 31, 0, 69, 0,
	22, 0, 0, 0, 0, 21, 13, 12, 0, 14,
	0, 25, 0, 26, 0, 0, 15, 0, 0, 0,
	16, 17, 30, 32, 0, 18, 28, 0, 0, 29,
	0, 0, 19, 0, 24, 0, 50, 0, 34, 155,
	51, 52, 53, 54, 0, 0, 0, 0, 63, 64,
	0, 65, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 27,
	9, 545, 49, 0, 0, 70, 0, 0, 0, 0,
	0, 0, 0, 0, 45, 46, 0, 0, 0, 0,
	47, 0, 48, 43, 44, 55, 56, 57, 58, 59,
	60, 61, 62, 0, 0, 0, 42, 0, 0, 0,
	0, 20, 66, 67, 0, 0, 0, 0, 40, 0,
	0, 31, 0, 69, 0, 22, 0, 0, 0, 0,
	21, 13, 12, 0, 14, 0, 25, 538, 26, 0,
	0, 15, 0, 0, 0, 16, 17, 30, 32, 0,
	18, 28, 0, 0, 29, 0, 0, 19, 0, 24,
	0, 50, 0, 34, 155, 51, 52, 53, 54, 0,
	0, 0, 0, 63, 64, 0, 65, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 27, 9, 0, 49, 0, 0,
	70, 0, 0, 0, 0, 0, 0, 0, 0, 45,
	46, 0, 0, 0, 0, 47, 0, 48, 43, 44,
	55, 56, 57, 58, 59, 60, 61, 62, 0, 0,
	0, 42, 0, 0, 0, 0, 20, 66, 67, 0,
	0, 0, 0, 40, 0, 0, 31, 0, 69, 0,
	22, 0, 0, 0, 0, 21, 13, 12, 0, 14,
	0, 25, 0, 26, 493, 0, 15, 0, 0, 0,
	16, 17, 30, 32, 0, 18, 28, 0, 0, 29,
	0, 0, 19, 0, 24, 0, 50, 0, 34, 155,
	51, 52, 53, 54, 0, 0, 0, 0, 63, 64,
	0, 65, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 27,
	9, 0, 49, 0, 0, 70, 0, 0, 0, 0,
	0, 0, 0, 0, 45, 46, 0, 0, 0, 0,
	47, 0, 48, 43, 44, 55, 56, 57, 58, 59,
	60, 61, 62, 0, 0, 0, 42, 0, 0, 0,
	0, 20, 66, 67, 0, 0, 0, 0, 40, 0,
	0, 31, 0, 69, 0, 22, 0, 0, 0, 0,
	21, 13, 12, 474, 14, 0, 25, 0, 26, 0,
	0, 15, 0, 0, 0, 16, 17, 30, 32, 0,
	18, 28, 0, 0, 29, 0, 0, 19, 0, 24,
	0, 50, 0, 34, 155, 51, 52, 53, 54, 0,
	0, 0, 0, 63, 64, 0, 65, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 27, 9, 0, 49, 0, 0,
	70, 0, 0, 0, 0, 0, 0, 0, 0, 45,
	46, 0, 0, 0, 0, 47, 0, 48, 43, 44,
	55, 56, 57, 58, 59, 60, 61, 62, 0, 0,
	0, 42, 0, 0, 0, 432, 20, 66, 67, 0,
	0, 0, 0, 40, 0, 0, 31, 0, 69, 0,
	22, 0, 0, 0, 0, 21, 13, 12, 0, 14,
	0, 25, 0, 26, 0, 0, 15, 0, 0, 0,
	16, 17, 30, 32, 0, 18, 28, 0, 0, 29,
	0, 0, 19, 0, 24, 0, 50, 0, 34, 155,
	51, 52, 53, 54, 0, 0, 0, 0, 63, 64,
	0, 65, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 27,
	9, 0, 49, 0, 0, 70, 0, 0, 0, 0,
	0, 0, 0, 0, 45, 46, 0, 0, 0, 0,
	47, 0, 48, 43, 44, 55, 56, 57, 58, 59,
	60, 61, 62, 0, 0, 0, 42, 0, 0, 0,
	0, 20, 66, 67, 0, 0, 0, 0, 40, 0,
	0, 31, 0, 69, 0, 22, 0, 0, 0, 0,
	21, 13, 12, 0, 14, 0, 25, 0, 26, 0,
	0, 15, 0, 0, 0, 16, 17, 30, 32, 0,
	18, 28, 0, 0, 29, 0, 0, 19, 0, 24,
	0, 50, 0, 34, 155, 51, 52, 53, 54, 0,
	0, 0, 0, 63, 64, 0, 65, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 27, 9, 368, 49, 0, 0,
	70, 0, 0, 0, 0, 0, 0, 0, 0, 45,
	46, 0, 0, 0, 0, 47, 0, 48, 43, 44,
	55, 56, 57, 58, 59, 60, 61, 62, 0, 0,
	0, 42, 0, 0, 0, 0, 20, 66, 67, 0,
	0, 0, 0, 40, 0, 0, 31, 0, 69, 0,
	22, 0, 0, 0, 0, 21, 13, 12, 0, 14,
	0, 25, 0, 26, 0, 0, 15, 0, 0, 0,
	16, 17, 30, 32, 0, 18, 28, 0, 0, 29,
	0, 0, 19, 0, 24, 0, 50, 0, 34, 6,
	51, 52, 53, 54, 0, 0, 0, 0, 63, 64,
	0, 65, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 27,
	9, 263, 49, 0, 0, 70, 0, 0, 0, 0,
	0, 0, 0, 0, 45, 46, 0, 0, 0, 0,
	47, 0, 48, 43, 44, 55, 56, 57, 58, 59,
	60, 61, 62, 0, 0, 0, 42, 0, 0, 0,
	0, 20, 66, 67, 0, 0, 0, 0, 40, 0,
	0, 31, 0, 69, 0, 22, 0, 0, 0, 0,
	21, 13, 12, 0, 14, 0, 25, 0, 26, 0,
	0, 15, 0, 0, 0, 16, 17, 30, 32, 0,
	18, 28, 0, 0, 29, 0, 0, 19, 0, 24,
	0, 50, 0, 34, 155, 51, 52, 53, 54, 0,
	0, 0, 0, 63, 64, 0, 65, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 7,
	0, 0, 0, 0, 27, 9, 0, 49, 0, 0,
	70, 0, 0, 0, 0, 0, 0, 0, 0, 45,
	46, 0, 0, 0, 0, 47, 0, 48, 43, 44,
	55, 56, 57, 58, 59, 60, 61, 62, 0, 0,
	0, 42, 0, 0, 0, 0, 20, 66, 67, 0,
	0, 0, 0, 40, 0, 0, 31, 0, 69, 0,
	22, 0, 0, 0, 0, 21, 13, 12, 0, 14,
	0, 25, 0, 26, 0, 0, 15, 0, 0, 0,
	16, 17, 30, 32, 0, 18, 28, 0, 0, 29,
	0, 0, 19, 0, 24, 0, 50, 0, 34, 155,
	51, 52, 53, 54, 0, 0, 0, 0, 63, 64,
	0, 65, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 485, 0, 0, 27,
	9, 0, 49, 0, 0, 70, 0, 0, 0, 0,
	0, 0, 0, 0, 45, 46, 0, 0, 0, 0,
	47, 0, 48, 43, 44, 55, 56, 57, 58, 59,
	60, 61, 62, 0, 0, 0, 42, 0, 0, 0,
	0, 20, 0, 0, 0, 0, 0, 0, 40, 0,
	0, 31, 0, 69, 0, 22, 0, 0, 0, 0,
	21, 13, 12, 0, 14, 0, 25, 0, 26, 0,
	0, 15, 0, 0, 0, 16, 17, 30, 0, 0,
	18, 28, 0, 0, 29, 0, 0, 19, 0, 24,
	0, 50, 155, 51, 52, 53, 54, 0, 0, 0,
	0, 63, 64, 0, 65, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 534,
	0, 0, 0, 0, 27, 9, 0, 49, 0, 0,
	70, 0, 0, 0, 0, 0, 0, 45, 46, 0,
	0, 0, 0, 47, 0, 48, 43, 44, 55, 56,
	57, 58, 59, 60, 61, 62, 0, 0, 0, 42,
	0, 0, 0, 0, 20, 0, 0, 0, 0, 0,
	0, 40, 0, 0, 31, 0, 69, 0, 22, 0,
	0, 0, 0, 21, 13, 12, 0, 14, 0, 25,
	0, 26, 0, 0, 15, 0, 0, 0, 16, 17,
	30, 0, 0, 18, 28, 0, 0, 29, 0, 0,
	19, 0, 24, 0, 50, 155, 51, 52, 53, 54,
	0, 0, 0, 0, 63, 64, 0, 65, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 434, 0, 0, 0, 0, 27, 9, 0,
	49, 0, 0, 70, 0, 0, 0, 0, 0, 0,
	45, 46, 0, 0, 0, 0, 47, 0, 48, 43,
	44, 55, 56, 57, 58, 59, 60, 61, 62, 0,
	0, 0, 42, 0, 0, 0, 0, 20, 0, 0,
	0, 0, 0, 0, 40, 0, 0, 31, 0, 69,
	0, 22, 0, 0, 0, 0, 21, 13, 12, 0,
	14, 0, 25, 0, 26, 0, 0, 15, 0, 0,
	0, 16, 17, 30, 0, 0, 18, 28, 0, 0,
	29, 0, 0, 19, 0, 24, 0, 50, 155, 51,
	52, 53, 54, 0, 0, 0, 0, 63, 64, 0,
	65, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 400, 0, 0, 0, 0,
	27, 9, 0, 49, 0, 0, 70, 0, 0, 0,
	0, 0, 0, 45, 46, 0, 0, 0, 0, 47,
	0, 48, 43, 44, 55, 56, 57, 58, 59, 60,
	61, 62, 0, 0, 0, 42, 0, 0, 0, 0,
	20, 0, 0, 0, 0, 0, 0, 40, 0, 0,
	31, 0, 69, 0, 22, 0, 0, 0, 0, 21,
	13, 12, 0, 14, 0, 25, 0, 26, 0, 0,
	15, 0, 0, 0, 16, 17, 30, 0, 0, 18,
	28, 0, 0, 29, 0, 0, 19, 0, 24, 0,
	50, 155, 51, 52, 53, 54, 0, 0, 0, 0,
	63, 64, 0, 65, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 383, 0,
	0, 0, 0, 27, 9, 0, 49, 0, 0, 70,
	0, 0, 0, 0, 0, 0, 45, 46, 0, 0,
	0, 0, 47, 0, 48, 43, 44, 55, 56, 57,
	58, 59, 60, 61, 62, 0, 0, 0, 42, 0,
	0, 0, 0, 20, 0, 0, 0, 0, 0, 0,
	40, 0, 0, 31, 0, 69, 0, 22, 0, 0,
	0, 0, 21, 13, 12, 0, 14, 0, 25, 0,
	26, 0, 0, 15, 0, 0, 0, 16, 17, 30,
	0, 0, 18, 28, 0, 0, 29, 0, 0, 19,
	0, 24, 0, 50, 155, 51, 52, 53, 54, 0,
	0, 0, 0, 63, 64, 0, 65, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 27, 9, 0, 49,
	0, 0, 70, 0, 0, 0, 0, 0, 0, 45,
	46, 0, 0, 0, 0, 47, 0, 48, 43, 44,
	55, 56, 57, 58, 59, 60, 61, 62, 0, 0,
	0, 42, 0, 0, 0, 0, 20, 0, 0, 0,
	0, 0, 0, 40, 0, 0, 31, 0, 69, 0,
	22, 0, 0, 0, 0, 21, 13, 12, 0, 14,
	0, 25, 0, 26, 0, 0, 15, 0, 0, 0,
	16, 17, 30, 0, 0, 18, 28, 0, 0, 29,
	0, 0, 19, 0, 24, 0, 50, 0, 155, 51,
	52, 53, 54, 0, 0, 0, 0, 63, 64, 0,
	65, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 27,
	9, 452, 49, 0, 0, 70, 0, 0, 155, 51,
	52, 53, 54, 45, 46, 0, 0, 63, 64, 47,
	65, 48, 43, 44, 55, 56, 57, 58, 59, 60,
	61, 62, 0, 0, 0, 42, 0, 0, 0, 0,
	0, 520, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 69, 45, 46, 0, 0, 0, 0, 47,
	0, 48, 43, 44, 55, 56, 57, 58, 59, 60,
	61, 62, 0, 0, 0, 42, 217, 218, 219, 220,
	222, 223, 224, 225, 226, 227, 228, 229, 221, 0,
	50, 0, 69, 0, 0, 0, 0, 0, 453, 0,
	155, 51, 52, 53, 54, 0, 0, 0, 0, 63,
	64, 0, 65, 0, 0, 0, 0, 230, 231, 0,
	0, 0, 0, 0, 0, 0, 49, 0, 0, 70,
	50, 0, 0, 331, 0, 0, 0, 0, 521, 0,
	0, 0, 0, 0, 0, 45, 46, 0, 0, 0,
	0, 47, 0, 48, 43, 44, 55, 56, 57, 58,
	59, 60, 61, 62, 0, 0, 49, 42, 0, 70,
	155, 51, 52, 53, 54, 0, 0, 0, 0, 63,
	64, 0, 65, 0, 69, 0, 0, 0, 0, 155,
	51, 52, 53, 54, 0, 0, 0, 310, 63, 64,
	0, 65, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 45, 46, 0, 0, 0,
	0, 47, 50, 48, 43, 44, 55, 56, 57, 58,
	59, 60, 61, 62, 45, 46, 0, 42, 0, 0,
	47, 0, 48, 43, 44, 55, 56, 57, 58, 59,
	60, 61, 62, 0, 69, 0, 42, 0, 49, 0,
	0, 70, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 69, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 50, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 50, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 49, 0,
	0, 70, 174, 176, 175, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 49, 0, 0,
	70, 0, 198, 0, 199, 172, 173, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 174, 176, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	184, 0, 0, 0, 0, 0, 0, 198, 0, 199,
	172, 173, 177, 179, 178, 191, 192, 189, 190, 193,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 174, 176, 175, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 184, 0, 0, 0, 0,
	0, 0, 198, 0, 199, 172, 173, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 174, 176, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	184, 0, 0, 0, 0, 431, 0, 198, 0, 199,
	172, 173, 177, 179, 178, 191, 192, 189, 190, 193,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 174, 176, 175, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 184, 0, 0, 0, 0,
	430, 0, 198, 0, 199, 172, 173, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 174, 176, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	184, 0, 0, 0, 0, 378, 0, 198, 0, 199,
	172, 173, 177, 179, 178, 191, 192, 189, 190, 193,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 174, 176, 175, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 184, 0, 0, 0, 0,
	377, 0, 198, 0, 199, 172, 173, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 174, 176, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	184, 0, 0, 0, 0, 376, 0, 198, 0, 199,
	172, 173, 177, 179, 178, 191, 192, 189, 190, 193,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 174, 176, 175, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 184, 0, 0, 0, 0,
	355, 0, 198, 0, 199, 172, 173, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 174, 176, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	184, 0, 0, 0, 0, 351, 0, 198, 510, 199,
	172, 173, 177, 179, 178, 191, 192, 189, 190, 193,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 174, 176, 175, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 184, 0, 0, 0, 0,
	345, 0, 198, 0, 199, 172, 173, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 174, 176, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	184, 0, 0, 380, 0, 0, 0, 198, 0, 199,
	172, 173, 177, 179, 178, 191, 192, 189, 190, 193,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 174, 176, 175, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 184, 511, 0, 0, 0,
	0, 0, 198, 0, 199, 172, 173, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 174, 176, 175,
	0, 0, 490, 0, 0, 0, 0, 0, 0, 0,
	184, 320, 0, 0, 0, 0, 0, 198, 0, 199,
	172, 173, 177, 179, 178, 191, 192, 189, 190, 193,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 174, 176, 175, 0, 0, 364, 0, 0,
	0, 0, 0, 0, 0, 184, 171, 0, 0, 0,
	0, 0, 198, 360, 199, 172, 173, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 174, 176, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	184, 0, 0, 0, 0, 0, 0, 198, 0, 199,
	172, 173, 177, 179, 178, 191, 192, 189, 190, 193,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 176, 175, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 184, 0, 0, 0, 0,
	0, 198, 0, 199, 172, 173, 177, 179, 178, 191,
	192, 189, 190, 193, 194, 195, 196, 197, 187, 188,
	181, 182, 180, 183, 185, 186, 175, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 184,
	0, 0, 0, 0, 198, 0, 199, 172, 173, 177,
	179, 178, 191, 192, 189, 190, 193, 194, 195, 196,
	197, 187, 188, 181, 182, 180, 183, 185, 186, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 198, 184, 199, 172, 173, 177, 179, 178, 191,
	192, 189, 190, 193, 194, 195, 196, 197, 187, 188,
	181, 182, 180, 183, 185, 186, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 184,
	199, 172, 173, 177, 179, 178, 191, 192, 189, 190,
	193, 194, 195, 196, 197, 187, 188, 181, 182, 180,
	183, 185, 186, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 184, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	184, 179, 178, 191, 192, 189, 190, 193, 194, 195,
	196, 197, 187, 188, 181, 182, 180, 183, 185, 186,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 184,
}
var yyPact = [...]int{

	-1000, -1000, 1945, -1000, -1000, -1000, 551, 187, -1000, -1000,
	-1000, -1000, -63, 2810, -64, -65, 3155, 3155, 3155, -55,
	184, 3155, -1000, 3787, -66, -69, -70, -1000, -14, 3155,
	205, 289, 276, 179, 204, 231, 219, 3029, -1000, -1000,
	-75, -1000, 3155, -55, -55, 3155, 3155, 3155, 3155, 3155,
	-78, 3155, -80, 3155, 3155, 3155, 3155, 3155, 3155, 3155,
	3155, 3155, 3155, 3155, 3155, 3155, -1000, -1000, -1000, -1000,
	-56, 87, 3967, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, 3155, -78, 3155, 3155, -80, 3155, 3155, 3155,
	3155, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 82,
	83, -1000, 1820, 3155, 158, 3155, 3155, 3155, 80, 3967,
	56, 55, 110, -1000, -1000, 109, -1000, 308, 108, -1000,
	3967, -1000, 3155, 3155, 3155, 3155, 3155, 3155, 3155, 3155,
	3155, 3155, 3155, 3155, 3155, 3155, 3155, 3155, 3155, 3155,
	3155, 3155, 3155, 3155, 3155, 3155, 3155, 3155, 3136, 3155,
	-55, 3155, 192, -1000, 3742, 54, -1000, 196, -1000, 194,
	-1000, -44, -81, 2810, -82, 52, 288, 3066, 3155, 3155,
	3155, 3155, 3155, 3155, 3155, 3155, 3155, 3155, 3155, 3155,
	-1000, -1000, 3155, -1000, -1000, -1000, 242, 242, 242, 242,
	3607, 3155, 3967, 3155, 3967, 3967, 242, 242, 242, 242,
	242, 242, 242, 242, 4091, 536, 4091, 3155, -1000, -1000,
	-1000, 193, -1000, -1000, -1000, -1000, -1000, 3562, -83, 51,
	337, 3967, 3517, -1000, -1000, -1000, -1000, -55, -1000, 184,
	3155, -1000, 3155, 683, 4162, 4011, 4091, 4054, 4195, 799,
	367, 304, 304, 304, 242, 242, 242, 242, 313, 313,
	291, 291, 291, 291, 291, 249, 249, 249, 249, 3922,
	3155, 4128, 321, -1000, -1000, 3832, 68, -1000, 307, 1695,
	-1000, -1000, -84, -46, -1000, 3155, -1000, 3155, -1000, -1000,
	4091, 3155, 4091, 4091, 4091, 4091, 4091, 4091, 4091, 4091,
	4091, 4091, 4091, 4091, 3472, -1000, 3427, 3382, 3155, 3652,
	-1000, 2687, 3155, 3155, 3155, 74, -1000, -1000, 3967, -1000,
	3155, 4128, -94, -55, 78, 2564, 192, 3155, -1000, 81,
	-1000, 172, 3337, 3292, 1570, 799, 2441, -1000, -1000, 4091,
	-1000, -1000, -1000, -1000, 91, 50, 3967, -1000, 49, 47,
	4128, 45, -1000, 38, -1000, -55, -88, 2934, -1000, -1000,
	-1000, -1000, 3967, 142, -118, 318, -1000, 275, -1000, -1000,
	14, -1000, -1000, -1000, -1000, 187, -62, 84, -1000, -1000,
	178, 208, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	2810, 287, 13, -1000, -1000, 1445, 11, 3155, -41, -1000,
	168, -1000, -1000, 2195, 78, -1000, 2934, -130, 312, -1000,
	-1000, 3877, -55, -89, 1320, -1000, -90, -47, 284, 81,
	89, -1000, -1000, -1000, 187, -1000, 103, -1000, 306, -1000,
	-1000, -1000, -1000, 2070, 10, -1000, -119, -1000, 3155, 77,
	-67, -4, 156, -1000, -1000, -1000, -123, -124, -1000, 2934,
	2974, -1000, 2934, -6, 117, -1000, -53, 81, -1000, 182,
	-1000, -1000, -1000, 178, 3155, 2070, -1000, 2318, 3697, -1000,
	-1000, -1000, -1000, -1000, -7, 1195, 2195, -1000, -1000, 3967,
	-55, -92, -125, -1000, 226, -1000, 1070, -1000, -1000, 305,
	-1000, 3967, -1000, -1000, -1000, -1000, 2070, -1000, -8, -1000,
	-1000, 2934, -1000, -127, 117, -1000, 945, 3155, 820, 2070,
	-1000, -128, -54, -1000, -1000, 3967, -11, -1000, -1000, -1000,
	695, -1000,
}
var yyPgo = [...]int{

	0, 316, 458, 457, 452, 451, 450, 12, 448, 4,
	446, 23, 445, 1, 444, 373, 371, 443, 442, 8,
	14, 441, 440, 9, 0, 439, 434, 31, 51, 433,
	432, 431, 430, 429, 24, 426, 424, 423, 13, 351,
	422, 28, 401, 29, 399, 25, 397, 27, 11, 2,
	10, 394, 393, 3, 392, 21, 390, 386, 384, 383,
	16, 382, 380, 379, 15, 377, 6, 360, 352, 348,
	347, 5,
}
var yyR1 = [...]int{

	0, 67, 68, 68, 68, 68, 68, 68, 68, 68,
	68, 68, 68, 68, 68, 68, 68, 68, 68, 68,
	68, 68, 68, 68, 68, 68, 68, 68, 68, 68,
	68, 68, 68, 68, 68, 68, 68, 68, 68, 68,
	68, 68, 68, 68, 68, 68, 68, 68, 68, 68,
	68, 68, 68, 68, 68, 68, 68, 68, 68, 68,
	68, 68, 68, 68, 68, 68, 68, 68, 68, 69,
	69, 69, 69, 69, 69, 69, 5, 5, 8, 8,
	7, 9, 9, 9, 10, 10, 6, 6, 6, 6,
	6, 13, 13, 12, 12, 12, 11, 11, 11, 11,
	11, 11, 11, 11, 11, 11, 11, 11, 11, 11,
	11, 11, 11, 11, 11, 11, 11, 11, 11, 11,
	57, 57, 58, 58, 59, 59, 54, 54, 55, 56,
	56, 29, 29, 30, 30, 31, 31, 32, 32, 33,
	33, 34, 34, 35, 35, 37, 37, 37, 37, 38,
	38, 38, 71, 71, 36, 36, 48, 48, 48, 48,
	49, 50, 50, 51, 51, 52, 52, 52, 52, 52,
	52, 53, 53, 40, 40, 41, 42, 42, 43, 43,
	44, 44, 45, 46, 46, 47, 70, 70, 15, 15,
	14, 14, 1, 1, 60, 60, 61, 62, 62, 63,
	63, 64, 64, 64, 64, 64, 64, 65, 65, 66,
	66, 16, 21, 21, 22, 22, 23, 23, 17, 17,
	4, 4, 2, 2, 3, 3, 19, 19, 20, 20,
	20, 18, 18, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 24, 24, 39, 39, 26,
	27, 28, 28, 28,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 3,
	1, 1, 2, 3, 2, 0, 1, 1, 3, 3,
	1, 2, 0, 1, 1, 1, 3, 1, 1, 5,
	7, 9, 5, 3, 3, 3, 3, 3, 3, 1,
	2, 6, 7, 9, 5, 1, 6, 3, 3, 2,
	0, 9, 1, 3, 0, 4, 3, 1, 3, 1,
	4, 5, 6, 1, 3, 6, 7, 3, 6, 1,
	4, 0, 1, 3, 1, 3, 4, 4, 5, 0,
	5, 4, 1, 1, 1, 4, 1, 2, 4, 3,
	1, 0, 1, 3, 1, 3, 1, 4, 2, 6,
	4, 1, 4, 3, 1, 1, 3, 1, 1, 3,
	3, 1, 1, 1, 3, 1, 0, 1, 6, 5,
	1, 2, 1, 1, 2, 0, 3, 1, 1, 1,
	2, 1, 1, 1, 1, 1, 1, 3, 1, 1,
	3, 10, 1, 0, 1, 3, 4, 6, 0, 1,
	0, 1, 0, 1, 0, 1, 1, 2, 1, 1,
	1, 0, 2, 3, 4, 2, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 2, 2,
	2, 2, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 2,
	2, 2, 2, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 5, 4, 3, 4, 2, 2, 4,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 1, 2, 4, 2, 1, 1, 0, 1, 1,
	1, 1, 4, 2,
}
var yyChk = [...]int{

	-1000, -67, -10, -6, -11, -16, 4, 154, -15, 160,
	-30, -32, 97, 96, 99, 106, 110, 111, 115, 122,
	76, 95, 90, -24, 124, 101, 103, 159, 116, 119,
	112, 86, 113, -14, 128, -29, -31, -27, -25, -1,
	83, -26, 71, 58, 59, 49, 50, 55, 57, 162,
	126, 5, 6, 7, 8, 60, 61, 62, 63, 64,
	65, 66, 67, 13, 14, 16, 77, 78, -28, 88,
	165, -5, -24, 86, -69, -68, 76, 77, 78, 79,
	80, 81, 71, 126, 4, 5, 6, 7, 8, 13,
	14, 10, 11, 12, 56, 70, 82, 83, 73, 74,
	75, 95, 96, 97, 98, 99, 100, 101, 102, 103,
	104, 105, 116, 117, 118, 119, 120, 121, 122, 123,
	124, 125, 111, 112, 113, 114, 115, 134, 106, 107,
	108, 109, 110, 135, 136, 131, 132, 154, 129, 130,
	128, 137, 138, 140, 139, 141, 142, 156, 155, -7,
	-8, 86, -13, 162, -11, 4, 162, 162, -39, -24,
	-39, -39, -40, -41, -28, -42, -43, 88, -44, -45,
	-24, 159, 33, 34, 10, 12, 11, 35, 37, 36,
	51, 49, 50, 52, 68, 53, 54, 47, 48, 40,
	41, 38, 39, 42, 43, 44, 45, 46, 30, 32,
	162, 162, 162, 160, -24, 86, 31, -4, 37, 128,
	-1, 86, 73, 74, 73, 75, 74, 17, 18, 19,
	20, 29, 21, 22, 23, 24, 25, 26, 27, 28,
	58, 59, 162, -24, -27, -27, -24, -24, -24, -24,
	-24, 162, -24, 162, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, 160, -28, 159,
	159, 157, -12, 161, -11, -16, -15, -24, 97, -34,
	-35, -24, -24, 159, 159, 159, 159, 9, 159, 9,
	17, 159, 9, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, -24, -24, -24,
	31, -24, -46, -47, -27, -24, -54, -55, 86, -13,
	159, 159, 86, 86, 160, 162, -11, 162, 159, 31,
	-24, 37, -24, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, 163, -24, -24, 15, -24,
	86, 163, 162, 159, 9, 163, -41, -43, -24, -45,
	31, -24, -70, 9, 105, 163, 9, 17, 161, 162,
	160, -60, -24, -24, -13, -24, 163, 163, 163, -24,
	161, -33, -11, 31, -24, -34, -24, -37, 160, 31,
	-24, 163, -47, -48, -27, 37, 134, 69, -56, -11,
	31, -55, -24, -57, -21, -22, -23, -17, -19, -20,
	30, -9, 135, 136, -7, 157, 154, -60, 161, -61,
	-62, -63, 123, -64, 81, 80, 79, 76, 77, 78,
	163, 163, 75, -11, 31, -13, 163, 159, -38, 159,
	-38, 159, 159, 163, 15, -27, 162, -49, -51, -50,
	-52, -24, 37, 134, -13, -59, 117, 118, 163, 9,
	-2, 37, -20, -7, 157, 161, -65, -66, 88, -64,
	-11, 31, 159, -13, 98, 159, -34, 161, 108, 109,
	-38, 107, -38, -53, -11, 31, -48, -49, 164, 9,
	15, -27, 162, 104, 162, 160, -18, 31, -23, -3,
	158, -7, 159, 9, 17, -13, 159, 163, -24, -71,
	31, 159, 161, 159, 107, -13, 163, 163, -50, -24,
	37, 134, -49, 159, -58, -9, -13, 160, -19, 88,
	-66, -24, -36, -11, 31, -71, -13, 159, 102, -53,
	-27, 162, 163, 88, 35, 161, -13, 17, -13, -13,
	159, -49, 163, -9, 161, -24, 100, 163, 160, 159,
	-13, 161,
}
var yyDef = [...]int{

	85, -2, 1, 84, 86, 87, 0, 0, 90, 92,
	97, 98, 0, 0, 0, 0, 307, 307, 307, 0,
	0, 0, 109, 0, 0, 0, 0, 115, 0, 0,
	0, 0, 220, 0, 0, 133, 0, 305, 306, 190,
	0, 310, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 301, 0, 192, 193, 309, 311,
	0, 0, 287, 76, 77, 69, 70, 71, 72, 73,
	74, 75, 12, 39, 2, 3, 4, 5, 6, 45,
	-2, 7, 8, 9, 10, 11, 13, 14, 15, 16,
	17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
	27, 28, 29, 30, 31, 32, 33, 34, 35, 36,
	37, 38, 40, 41, 42, 43, 44, 47, 48, 49,
	50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
	60, 61, 62, 63, 64, 65, 66, 67, 68, 0,
	80, 78, 0, 0, 0, 0, 141, 0, 0, 308,
	0, 0, 0, 174, 175, 0, 177, 178, 0, 181,
	182, 110, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 0, 0, 119, 0, 221, 0,
	191, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	248, 250, 0, 235, 249, 251, 269, 270, 271, 272,
	0, 0, 288, 0, 290, 291, 292, 293, 294, 295,
	296, 297, 298, 299, 300, 302, 304, 0, 313, 88,
	89, 0, 91, 96, 93, 94, 95, 0, 0, 0,
	142, 144, 0, 103, 104, 105, 106, 0, 107, 0,
	0, 108, 0, 252, 253, 254, 255, 256, 257, 258,
	259, 260, 261, 262, 263, 264, 265, 266, 267, 268,
	-2, -2, -2, -2, -2, -2, -2, -2, -2, 0,
	0, 285, 186, 183, 185, 0, 0, 127, 0, 0,
	117, 118, 0, 0, 195, 0, 134, 0, 137, 92,
	233, 0, 236, 237, 238, 239, 240, 241, 242, 243,
	244, 245, 246, 247, 0, 282, 0, 0, 0, 0,
	79, 0, 0, 141, 0, 0, 173, 176, 179, 180,
	0, 284, 0, 187, 0, 0, 0, 0, 120, -2,
	195, 0, 0, 0, 0, 234, 0, 286, 289, 303,
	312, 99, 139, 92, 0, 0, 143, 102, 149, 149,
	283, 0, 184, 0, 156, 0, 0, 161, 114, 129,
	92, 126, 128, 124, 0, 212, 214, 222, 219, 226,
	0, 228, 229, 230, 81, 0, 0, 0, 189, 194,
	0, 197, 198, 199, 201, 202, 203, 204, 205, 206,
	0, 0, 0, 131, 92, 0, 0, 141, 0, 149,
	0, 149, 111, 0, 0, 157, 161, 0, 160, 164,
	162, 166, 0, 0, 0, 116, 0, 0, 231, 218,
	224, 223, 227, 82, 0, 188, 0, 208, 209, 200,
	132, 92, 138, 135, 0, 100, 0, 145, 0, 0,
	0, 0, 0, 112, 171, 92, 0, 0, 159, 161,
	0, 168, 161, 0, 0, 92, 0, 0, 215, 0,
	225, 83, 196, 0, 0, 136, 140, 0, 0, 92,
	152, 153, 146, 147, 0, 0, 0, 158, 163, 165,
	0, 0, 0, 130, 0, 122, 0, 92, 232, 216,
	207, 210, 101, 154, 92, 92, 151, 148, 0, 113,
	167, 161, 170, 0, 0, 125, 0, 0, 0, 150,
	172, 0, 0, 123, 211, 217, 0, 169, 92, 155,
	0, 121,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 55, 3, 3, 165, 54, 37, 3,
	162, 163, 52, 49, 9, 50, 51, 53, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 31, 159,
	43, 17, 45, 30, 67, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 69, 3, 164, 36, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 160, 35, 161, 57,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 10, 11, 12,
	13, 14, 15, 16, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 32, 33, 34, 38,
	39, 40, 41, 42, 44, 46, 47, 48, 56, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 68, 70,
	71, 72, 73, 74, 75, 76, 77, 78, 79, 80,
	81, 82, 83, 84, 85, 86, 87, 88, 89, 90,
	91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
	111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128, 129, 130,
	131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
	141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
	151, 152, 153, 154, 155, 156, 157, 158,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:245
		{
			fmt.Println(yyDollar[1].node)
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:264
		{
			yyVAL.node = Node("identifier")
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:265
		{
			yyVAL.node = Node("reserved")
		}
	case 78:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:269
		{
			yyVAL.node = Node("NamespaceParts").append(Node(yyDollar[1].token))
		}
	case 79:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:270
		{
			yyVAL.node = yyDollar[1].node.append(Node(yyDollar[3].token))
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:274
		{
			yyVAL.node = yyDollar[1].node
		}
	case 81:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:278
		{
			yyVAL.node = Node("Name").append(yyDollar[1].node)
		}
	case 82:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:279
		{
			yyVAL.node = Node("Name").append(yyDollar[2].node).attribute("FullyQualified", "true")
		}
	case 83:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:280
		{
			yyVAL.node = Node("Name").append(yyDollar[3].node).attribute("Relative", "true")
		}
	case 84:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:284
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 85:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:285
		{
			yyVAL.node = Node("Statements")
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:289
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:290
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:291
		{
			yyVAL.node = yyDollar[2].node /*TODO: identifier stub, refactor it*/
		}
	case 89:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:292
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node)
		}
	case 90:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:293
		{
			yyVAL.node = yyDollar[1].node
		}
	case 91:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:297
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 92:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:298
		{
			yyVAL.node = Node("stmt")
		}
	case 93:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:302
		{
			yyVAL.node = yyDollar[1].node
		}
	case 94:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.node = yyDollar[1].node
		}
	case 95:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.node = yyDollar[1].node
		}
	case 96:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:307
		{
			yyVAL.node = yyDollar[2].node
		}
	case 97:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.node = yyDollar[1].node
		}
	case 98:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:309
		{
			yyVAL.node = yyDollar[1].node
		}
	case 99:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:311
		{
			yyVAL.node = Node("While").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("stmt").append(yyDollar[5].node))
		}
	case 100:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:317
		{
			yyVAL.node = Node("DoWhile").
				append(Node("expr").append(yyDollar[5].node)).
				append(Node("stmt").append(yyDollar[2].node))
		}
	case 101:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:323
		{
			yyVAL.node = Node("For").
				append(Node("expr1").append(yyDollar[3].node)).
				append(Node("expr2").append(yyDollar[5].node)).
				append(Node("expr3").append(yyDollar[7].node)).
				append(Node("stmt").append(yyDollar[9].node))
		}
	case 102:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:330
		{
			yyVAL.node = Node("Switch").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node)
		}
	case 103:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:331
		{
			yyVAL.node = Node("Break").append(yyDollar[2].node)
		}
	case 104:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:332
		{
			yyVAL.node = Node("Continue").append(yyDollar[2].node)
		}
	case 105:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:333
		{
			yyVAL.node = Node("Return").append(yyDollar[2].node)
		}
	case 106:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:334
		{
			yyVAL.node = yyDollar[2].node
		}
	case 107:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:335
		{
			yyVAL.node = yyDollar[2].node
		}
	case 108:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:336
		{
			yyVAL.node = yyDollar[2].node
		}
	case 109:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:337
		{
			yyVAL.node = Node("Echo").append(Node("InlineHtml").attribute("value", yyDollar[1].token))
		}
	case 110:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:338
		{
			yyVAL.node = yyDollar[1].node
		}
	case 111:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:340
		{
			yyVAL.node = Node("Unset").append(yyDollar[3].node)
		}
	case 112:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:342
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachVariable").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 113:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:349
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachKey").append(yyDollar[5].node)).
				append(Node("ForeachVariable").append(yyDollar[7].node)).
				append(yyDollar[9].node)
		}
	case 114:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:356
		{
			yyVAL.node = Node("Declare").append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 115:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:357
		{
			yyVAL.node = Node("")
		}
	case 116:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:359
		{
			yyVAL.node = Node("Try").
				append(yyDollar[3].node).
				append(yyDollar[5].node).
				append(yyDollar[6].node)
		}
	case 117:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:365
		{
			yyVAL.node = Node("Throw").append(yyDollar[2].node)
		}
	case 118:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:366
		{
			yyVAL.node = Node("GoTo").attribute("Label", yyDollar[2].token)
		}
	case 119:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:367
		{
			yyVAL.node = Node("Label").attribute("name", yyDollar[1].token)
		}
	case 120:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:370
		{
			yyVAL.node = Node("CatchList")
		}
	case 121:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:372
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[4].node).append(Node("Variable").attribute("name", yyDollar[5].token)).append(yyDollar[8].node)
		}
	case 122:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:375
		{
			yyVAL.node = Node("CatchNameList").append(yyDollar[1].node)
		}
	case 123:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:376
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 124:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:380
		{
			yyVAL.node = Node("")
		}
	case 125:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:381
		{
			yyVAL.node = Node("Finnaly").append(yyDollar[3].node)
		}
	case 126:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:385
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 127:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:386
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 128:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:390
		{
			yyVAL.node = Node("Const").attribute("name", yyDollar[1].token).append(yyDollar[3].node)
		}
	case 129:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:394
		{
			yyVAL.node = yyDollar[1].node
		}
	case 130:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:395
		{
			yyVAL.node = yyDollar[2].node
		}
	case 131:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:400
		{
			yyVAL.node = Node("If").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[5].node))
		}
	case 132:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:404
		{
			yyVAL.node = yyDollar[1].node.append(Node("ElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[6].node)))
		}
	case 133:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:410
		{
			yyVAL.node = yyDollar[1].node
		}
	case 134:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:412
		{
			yyVAL.node = yyDollar[1].node.append(Node("Else").append(Node("stmt").append(yyDollar[3].node)))
		}
	case 135:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:419
		{
			yyVAL.node = Node("AltIf").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[6].node))
		}
	case 136:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:423
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[7].node)))
		}
	case 137:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:429
		{
			yyVAL.node = yyDollar[1].node
		}
	case 138:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:431
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElse").append(Node("stmt").append(yyDollar[4].node)))
		}
	case 139:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:437
		{
			yyVAL.node = yyDollar[1].node
		}
	case 140:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:438
		{
			yyVAL.node = yyDollar[2].node
		}
	case 141:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:442
		{
			yyVAL.node = Node("")
		}
	case 142:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:443
		{
			yyVAL.node = yyDollar[1].node
		}
	case 143:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:446
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 144:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:447
		{
			yyVAL.node = Node("ExpressionList").append(yyDollar[1].node)
		}
	case 145:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:451
		{
			yyVAL.node = yyDollar[2].node
		}
	case 146:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:452
		{
			yyVAL.node = yyDollar[3].node
		}
	case 147:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:453
		{
			yyVAL.node = yyDollar[2].node
		}
	case 148:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:454
		{
			yyVAL.node = yyDollar[3].node
		}
	case 149:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:458
		{
			yyVAL.node = Node("CaseList")
		}
	case 150:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:460
		{
			yyVAL.node = yyDollar[1].node.append(Node("Case").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node))
		}
	case 151:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:464
		{
			yyVAL.node = yyDollar[1].node.append(Node("Default").append(yyDollar[4].node))
		}
	case 154:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:475
		{
			yyVAL.node = yyDollar[1].node
		}
	case 155:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:476
		{
			yyVAL.node = yyDollar[2].node
		}
	case 156:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:480
		{
			yyVAL.node = yyDollar[1].node
		}
	case 157:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:481
		{
			yyVAL.node = Node("Ref").append(yyDollar[2].node)
		}
	case 158:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:482
		{
			yyVAL.node = Node("List").append(yyDollar[3].node)
		}
	case 159:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:483
		{
			yyVAL.node = Node("ShortList").append(yyDollar[2].node)
		}
	case 160:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:487
		{ /* TODO: allow single trailing comma */
			yyVAL.node = yyDollar[1].node
		}
	case 161:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:491
		{
			yyVAL.node = Node("")
		}
	case 162:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:492
		{
			yyVAL.node = yyDollar[1].node
		}
	case 163:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:497
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 164:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:498
		{
			yyVAL.node = Node("ArrayPairList").append(yyDollar[1].node)
		}
	case 165:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:502
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 166:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:503
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node)
		}
	case 167:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:504
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(Node("Ref").append(yyDollar[4].node))
		}
	case 168:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:505
		{
			yyVAL.node = Node("ArrayElement").append(Node("Ref").append(yyDollar[2].node))
		}
	case 169:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:507
		{
			yyVAL.node = Node("ArrayElement").
				append(yyDollar[1].node).
				append(Node("ArrayList").append(yyDollar[5].node))
		}
	case 170:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:513
		{
			yyVAL.node = Node("ArrayElement").
				append(Node("ArrayList").append(yyDollar[3].node))
		}
	case 171:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:520
		{
			yyVAL.node = yyDollar[1].node
		}
	case 172:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:521
		{
			yyVAL.node = yyDollar[2].node
		}
	case 173:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:525
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 174:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:526
		{
			yyVAL.node = Node("GlobalVarList").append(yyDollar[1].node)
		}
	case 175:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:530
		{
			yyVAL.node = yyDollar[1].node
		}
	case 176:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:534
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 177:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:535
		{
			yyVAL.node = Node("StaticVarList").append(yyDollar[1].node)
		}
	case 178:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:539
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token)
		}
	case 179:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:540
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token).append(Node("expr").append(yyDollar[3].node))
		}
	case 180:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:544
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 181:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:545
		{
			yyVAL.node = Node("EchoList").append(yyDollar[1].node)
		}
	case 182:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:549
		{
			yyVAL.node = Node("Echo").append(yyDollar[1].node)
		}
	case 183:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:553
		{
			yyVAL.node = Node("UnsetVariablesList").append(yyDollar[1].node)
		}
	case 184:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:554
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 185:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:558
		{
			yyVAL.node = yyDollar[1].node
		}
	case 188:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:568
		{
			yyVAL.node = yyDollar[1].node.attribute("name", yyDollar[3].token).append(yyDollar[5].node)
		}
	case 189:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:569
		{
			yyVAL.node = Node("Class").attribute("name", yyDollar[2].token).append(yyDollar[4].node)
		}
	case 190:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:573
		{
			yyVAL.node = Node("Class").attribute(yyDollar[1].value, "true")
		}
	case 191:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:574
		{
			yyVAL.node = yyDollar[1].node.attribute(yyDollar[2].value, "true")
		}
	case 192:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:578
		{
			yyVAL.value = "abstract"
		}
	case 193:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:579
		{
			yyVAL.value = "final"
		}
	case 194:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:583
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 195:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:584
		{
			yyVAL.node = Node("Stmt")
		}
	case 196:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:588
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 197:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:592
		{
			yyVAL.node = yyDollar[1].node
		}
	case 198:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:593
		{
			yyVAL.node = Node("VarMemberModifier")
		}
	case 199:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:597
		{
			yyVAL.node = yyDollar[1].node
		}
	case 200:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:598
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 201:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:601
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 202:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:602
		{
			yyVAL.node = Node("ProtectedMemberModifier")
		}
	case 203:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:603
		{
			yyVAL.node = Node("PrivateMemberModifier")
		}
	case 204:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:604
		{
			yyVAL.node = Node("StaticMemberModifier")
		}
	case 205:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:605
		{
			yyVAL.node = Node("AbstractMemberModifier")
		}
	case 206:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:606
		{
			yyVAL.node = Node("FinalMemberModifier")
		}
	case 207:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:610
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 208:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:611
		{
			yyVAL.node = Node("PropertyList").append(yyDollar[1].node)
		}
	case 209:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:614
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token)
		}
	case 210:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:615
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token).append(Node("Default").append(yyDollar[3].node))
		}
	case 211:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser.y:620
		{
			yyVAL.node = Node("Function").
				attribute("name", yyDollar[3].token).
				attribute("returns_ref", yyDollar[2].value).
				append(yyDollar[5].node).
				append(yyDollar[7].node).
				append(yyDollar[9].node)
		}
	case 212:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:631
		{
			yyVAL.node = yyDollar[1].node
		}
	case 213:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:632
		{
			yyVAL.node = Node("Parameter list")
		}
	case 214:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:635
		{
			yyVAL.node = Node("Parameter list").append(yyDollar[1].node)
		}
	case 215:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:636
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 216:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:640
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token)
		}
	case 217:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:648
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token).
				append(yyDollar[6].node)
		}
	case 218:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:659
		{
			yyVAL.node = Node("No type")
		}
	case 219:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:660
		{
			yyVAL.node = yyDollar[1].node
		}
	case 220:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:664
		{
			yyVAL.value = "false"
		}
	case 221:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:665
		{
			yyVAL.value = "true"
		}
	case 222:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:669
		{
			yyVAL.value = "false"
		}
	case 223:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:670
		{
			yyVAL.value = "true"
		}
	case 224:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:674
		{
			yyVAL.value = "false"
		}
	case 225:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:675
		{
			yyVAL.value = "true"
		}
	case 226:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:679
		{
			yyVAL.node = yyDollar[1].node
		}
	case 227:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:680
		{
			yyVAL.node = yyDollar[2].node
			yyVAL.node.attribute("nullable", "true")
		}
	case 228:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:684
		{
			yyVAL.node = yyDollar[1].node
		}
	case 229:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:685
		{
			yyVAL.node = Node("array type")
		}
	case 230:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:686
		{
			yyVAL.node = Node("callable type")
		}
	case 231:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:690
		{
			yyVAL.node = Node("void")
		}
	case 232:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:691
		{
			yyVAL.node = yyDollar[2].node
		}
	case 233:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:695
		{
			yyVAL.node = Node("Assign").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 234:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:696
		{
			yyVAL.node = Node("AssignRef").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 235:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:697
		{
			yyVAL.node = Node("Clone").append(yyDollar[2].node)
		}
	case 236:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:698
		{
			yyVAL.node = Node("AssignAdd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 237:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:699
		{
			yyVAL.node = Node("AssignSub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 238:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:700
		{
			yyVAL.node = Node("AssignMul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 239:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:701
		{
			yyVAL.node = Node("AssignPow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 240:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:702
		{
			yyVAL.node = Node("AssignDiv").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 241:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:703
		{
			yyVAL.node = Node("AssignConcat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 242:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:704
		{
			yyVAL.node = Node("AssignMod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 243:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:705
		{
			yyVAL.node = Node("AssignAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 244:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:706
		{
			yyVAL.node = Node("AssignOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 245:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:707
		{
			yyVAL.node = Node("AssignXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:708
		{
			yyVAL.node = Node("AssignShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 247:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:709
		{
			yyVAL.node = Node("AssignShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 248:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:710
		{
			yyVAL.node = Node("PostIncrement").append(yyDollar[1].node)
		}
	case 249:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:711
		{
			yyVAL.node = Node("PreIncrement").append(yyDollar[2].node)
		}
	case 250:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:712
		{
			yyVAL.node = Node("PostDecrement").append(yyDollar[1].node)
		}
	case 251:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:713
		{
			yyVAL.node = Node("PreDecrement").append(yyDollar[2].node)
		}
	case 252:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:714
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 253:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:715
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 254:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:716
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 255:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:717
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 256:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:718
		{
			yyVAL.node = Node("Xor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 257:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:719
		{
			yyVAL.node = Node("BitwiseOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 258:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:720
		{
			yyVAL.node = Node("BitwiseAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 259:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:721
		{
			yyVAL.node = Node("BitwiseXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 260:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:722
		{
			yyVAL.node = Node("Concat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 261:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:723
		{
			yyVAL.node = Node("Add").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 262:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:724
		{
			yyVAL.node = Node("Sub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 263:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:725
		{
			yyVAL.node = Node("Mul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 264:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:726
		{
			yyVAL.node = Node("Pow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 265:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:727
		{
			yyVAL.node = Node("Div").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 266:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:728
		{
			yyVAL.node = Node("Mod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 267:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:729
		{
			yyVAL.node = Node("ShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 268:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:730
		{
			yyVAL.node = Node("ShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 269:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:731
		{
			yyVAL.node = Node("UnaryPlus").append(yyDollar[2].node)
		}
	case 270:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:732
		{
			yyVAL.node = Node("UnaryMinus").append(yyDollar[2].node)
		}
	case 271:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:733
		{
			yyVAL.node = Node("BooleanNot").append(yyDollar[2].node)
		}
	case 272:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:734
		{
			yyVAL.node = Node("BitwiseNot").append(yyDollar[2].node)
		}
	case 273:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:735
		{
			yyVAL.node = Node("Identical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 274:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:736
		{
			yyVAL.node = Node("NotIdentical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 275:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:737
		{
			yyVAL.node = Node("Equal").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 276:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:738
		{
			yyVAL.node = Node("NotEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 277:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:739
		{
			yyVAL.node = Node("Spaceship").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 278:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:740
		{
			yyVAL.node = Node("Smaller").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 279:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:741
		{
			yyVAL.node = Node("SmallerOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 280:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:742
		{
			yyVAL.node = Node("Greater").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 281:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:743
		{
			yyVAL.node = Node("GreaterOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 282:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:744
		{
			yyVAL.node = yyDollar[2].node
		}
	case 283:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:745
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 284:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:746
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 285:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:747
		{
			yyVAL.node = Node("Coalesce").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 286:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:748
		{
			yyVAL.node = Node("Empty").append(yyDollar[3].node)
		}
	case 287:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:749
		{
			yyVAL.node = Node("Include").append(yyDollar[2].node)
		}
	case 288:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:750
		{
			yyVAL.node = Node("IncludeOnce").append(yyDollar[2].node)
		}
	case 289:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:751
		{
			yyVAL.node = Node("Eval").append(yyDollar[3].node)
		}
	case 290:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:752
		{
			yyVAL.node = Node("Require").append(yyDollar[2].node)
		}
	case 291:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:753
		{
			yyVAL.node = Node("RequireOnce").append(yyDollar[2].node)
		}
	case 292:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:754
		{
			yyVAL.node = Node("CastInt").append(yyDollar[2].node)
		}
	case 293:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:755
		{
			yyVAL.node = Node("CastDouble").append(yyDollar[2].node)
		}
	case 294:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:756
		{
			yyVAL.node = Node("CastString").append(yyDollar[2].node)
		}
	case 295:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:757
		{
			yyVAL.node = Node("CastArray").append(yyDollar[2].node)
		}
	case 296:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:758
		{
			yyVAL.node = Node("CastObject").append(yyDollar[2].node)
		}
	case 297:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:759
		{
			yyVAL.node = Node("CastBool").append(yyDollar[2].node)
		}
	case 298:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:760
		{
			yyVAL.node = Node("CastUnset").append(yyDollar[2].node)
		}
	case 299:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:761
		{
			yyVAL.node = Node("Silence").append(yyDollar[2].node)
		}
	case 300:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:763
		{
			yyVAL.node = Node("Print").append(yyDollar[2].node)
		}
	case 301:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:764
		{
			yyVAL.node = Node("Yield")
		}
	case 302:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:765
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node)
		}
	case 303:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:766
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 304:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:767
		{
			yyVAL.node = Node("YieldFrom").append(yyDollar[2].node)
		}
	case 305:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:771
		{
			yyVAL.node = yyDollar[1].node
		}
	case 306:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:772
		{
			yyVAL.node = yyDollar[1].node
		}
	case 307:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:776
		{
			yyVAL.node = Node("")
		}
	case 308:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:777
		{
			yyVAL.node = yyDollar[1].node
		}
	case 309:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:781
		{
			yyVAL.node = yyDollar[1].node
		}
	case 310:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:785
		{
			yyVAL.node = yyDollar[1].node
		}
	case 311:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:789
		{
			yyVAL.node = Node("Variable").attribute("name", yyDollar[1].token)
		}
	case 312:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:790
		{
			yyVAL.node = yyDollar[3].node
		}
	case 313:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:791
		{
			yyVAL.node = Node("Variable").append(yyDollar[2].node)
		}
	}
	goto yystack /* stack new state and value */
}
